==> icons-vue-0.6.0.tgz: package/lib/watson-health/launch-study--3/24.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_WatsonHealthLaunchStudy_324 = {
  name: 'WatsonHealthLaunchStudy_324',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('circle', {
      attrs: {
        "cx": "23",
        "cy": "25",
        "r": "1"
      }
    }), createElement('path', {
      attrs: {
        "d": "M26,22v6H6V22H26m0-2H6a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V22a2,2,0,0,0-2-2Z"
      }
    }), createElement('polygon', {
      attrs: {
        "points": "20.59 4.59 17 8.17 17 0 15 0 15 8.17 11.41 4.59 10 6 16 12 22 6 20.59 4.59"
      }
    }), createElement('polygon', {
      attrs: {
        "points": "20.59 10.59 16 15.16 11.41 10.59 10 12 16 18 22 12 20.59 10.59"
      }
    }), createElement('rect', {
      attrs: {
        "width": "12",
        "height": "2",
        "x": "8",
        "y": "24"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthLaunchStudy_324;

==> icons-vue-10.6.1.tgz: package/lib/watson-health/launch-study--3/24.js <==
'use strict';

var __chunk_1 = require('../../chunk-d2faeea1.js');
var iconHelpers = require('@carbon/icon-helpers');

var virtual_WatsonHealthLaunchStudy_324 = {
  name: 'WatsonHealthLaunchStudy_324',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('circle', {
      attrs: {
        "cx": "23",
        "cy": "25",
        "r": "1"
      }
    }), createElement('path', {
      attrs: {
        "d": "M26 22v6H6v-6h20m0-2H6a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h20a2 2 0 0 0 2-2v-6a2 2 0 0 0-2-2zM20.59 4.59L17 8.17V0h-2v8.17l-3.59-3.58L10 6l6 6 6-6-1.41-1.41z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M20.59 10.59L16 15.16l-4.59-4.57L10 12l6 6 6-6-1.41-1.41zM8 24h12v2H8z"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthLaunchStudy_324;
